@@ -2,6 +2,6 @@ import pytest
 
 
 class TestQuotaon:
-    @pytest.mark.complete("quotaon -")
+    @pytest.mark.complete("quotaon -", require_cmd=True)
     def test_1(self, completion):
         assert completion
